==> cscec5b-rmat-impl-3.0.1-20221025.022706-21-sources.jar: com/ejianc/business/rmat/bean/CalculateOtherEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租金计算单-其他费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_calculate_other")
public class CalculateOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="calculate_id")
    private Long calculateId; // 结算id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型：0-新增，1-合同代入
    @TableField(value="cost_name")
    private String costName; // 费用名称
    @TableField(value="unit_tax_price")
    private BigDecimal unitTaxPrice; // 单价
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 单价(无税)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本期金额
    @TableField(value="mny")
    private BigDecimal mny; // 本期金额(无税)
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getCalculateId() {
        return calculateId;
    }

    public void setCalculateId(Long calculateId) {
        this.calculateId = calculateId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-rmat-impl-3.0.1-20230609.071328-202-sources.jar: com/ejianc/business/rmat/bean/CalculateOtherEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 租金计算单-其他费用
 *
 * @author generator
 *
 */
 @TableName("ejc_rmat_calculate_other")
public class CalculateOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="calculate_id")
    private Long calculateId; // 结算id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型：0-新增，1-合同代入
    @TableField(value="cost_name")
    private String costName; // 费用名称
    @TableField(value="unit_tax_price")
    private BigDecimal unitTaxPrice; // 单价
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 单价(无税)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本期金额
    @TableField(value="mny")
    private BigDecimal mny; // 本期金额(无税)
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="pk_amountlist")
    private String pkAmountlist; // 分录主键

    @TableField(value="htywnr")
    private String htywnr; // 分录名称




    public Long getCalculateId() {
        return calculateId;
    }

    public void setCalculateId(Long calculateId) {
        this.calculateId = calculateId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }
}
